@@ -98,13 +98,10 @@ class SymGroup(Group):
 
         try:
             return super().invoke(ctx)
-        except ClickException:
+        except (ClickException, Abort, Exit):
             raise
-        except (Abort, KeyboardInterrupt):
+        except KeyboardInterrupt:
             pass
-        except Exit as e:
-            if e.exit_code != 0:
-                raise e
         except Exception as e:
             if not is_prod_mode() or ctx.params.get("debug"):
                 raise e
