@@ -15,11 +15,11 @@ import requests
 from semver import VersionInfo
 
 from .config import Config
-from .contexts import push_env
+from .contexts import push_envs
 from .os import has_command, reset_fds
 
-REQ_TIMEOUT = 1
-INSTALL_TIMEOUT = 30
+REQ_TIMEOUT = 3
+INSTALL_TIMEOUT = 60
 V0 = VersionInfo.parse("0.0.0")
 
 
@@ -172,7 +172,9 @@ class SymUpdater:
             f"Using brew. You can also manually run `brew upgrade {Config.get_dir_name()}`.",
             fg="bright_black",
         )
-        with push_env("HOMEBREW_NO_AUTO_UPDATE", "1"):
+        with push_envs(
+            {"HOMEBREW_NO_AUTO_UPDATE": "1", "HOMEBREW_NO_INSTALL_CLEANUP": "1"}
+        ):
             res = self._update_with_command(
                 ["brew", "--repo", "symopsio/tap"], capture_output=True
             )
@@ -183,7 +185,7 @@ class SymUpdater:
                 ["git", "pull", "origin", "master"],
                 cwd=res.stdout.strip(),
             ) and self._update_with_checked_command(
-                ["brew", "upgrade", Config.get_dir_name()]
+                ["brew", "upgrade", "-f", Config.get_dir_name()]
             )
 
     def update_sitepackage(self) -> bool:
