@@ -17,6 +17,19 @@ def org(sandbox: Sandbox, uuid: UUID) -> str:
     return org
 
 
+@pytest.fixture
+def init_cli_name_tester(sandbox: Sandbox):
+    def func(cli_name: str, expected: str):
+        with sandbox.push_xdg_config_home():
+            init(cli_name)
+            assert Config.get_cli_name() == expected
+            # sym init must be done last to make sure cli stays in its own
+            # original state. otherwise, tests will bleed.
+            init("sym")
+
+    return func
+
+
 def test_get_org_with_xdg_config_home(sandbox: Sandbox, org: str) -> None:
     with push_env("XDG_CONFIG_HOME", str(sandbox.path / ".config")):
         assert Config()["org"] == org
@@ -80,15 +93,7 @@ def test_sym_config_exclusive_create_already_created(sandbox: Sandbox):
             assert f.read() == body
 
 
-def test_config_get_cli_name(sandbox: Sandbox):
-    with sandbox.push_xdg_config_home():
-        init("symflow")
-        assert Config.get_cli_name() == "sym-flow-cli"
-
-        init("unknown")
-        assert Config.get_cli_name() == "unknown"
-
-        # sym init must be done last to make sure cli stays in its own
-        # original state. otherwise, this will bleed into other tests.
-        init("sym")
-        assert Config.get_cli_name() == "sym-cli"
+def test_config_get_cli_name(init_cli_name_tester):
+    init_cli_name_tester("sym", "sym-cli")
+    init_cli_name_tester("symflow", "sym-flow-cli")
+    init_cli_name_tester("unknown", "unknown")
